#*********************************************************************************
# The contents of this file are subject to the vtiger CRM Public License Version 1.0
# ("License"); You may not use this file except in compliance with the License
# The Original Code is:  vtiger CRM Open Source
# The Initial Developer of the Original Code is vtiger.
# Portions created by vtiger are Copyright (C) vtiger.
# All Rights Reserved.
#
# ********************************************************************************

export VTIGERCRM_ROOTDIR=`dirname "$0"`/..
export USE_PHP=php

cd $VTIGERCRM_ROOTDIR

# Specify scannername to scan specific mailbox configured
# $USE_PHP -f vtigercron.php service="MailScanner" scannername="DEFAULT"
# Scan all the configured mailboxes
  $USE_PHP -f vtigercron.php service="MailScanner"
